==> nextcloud-13.0.1.tgz: nextcloud/apps/theming/l10n/et_EE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Eelvaate laadimine...",
    "Saved" : "Salvestatud",
    "Admin" : "Haldur",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "The given name is too long" : "Antud nimi on liiga pikk",
    "The given web address is too long" : "Antud veebiaadress on liiga pikk",
    "The given slogan is too long" : "Antud tunnuslause on liiga pikk",
    "The given color is invalid" : "Antud värv ei sobi",
    "There is no error, the file uploaded with success" : "Vigu pole, fail laetu edukalt üles",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaetud fail on suurem, kui php.ini failis määratud upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail on suurem, kui MAX_FILE_SIZE atribuut, mis seadistati HTML vormis",
    "No file was uploaded" : "Ühtegi faili ei latud üles",
    "Missing a temporary folder" : "Ajutine kausta on puudu",
    "Failed to write file to disk." : "Faili kettale kirjutamine ebaõnnestus.",
    "A PHP extension stopped the file upload." : "PHP laiendus seiskas faili üleslaadimise.",
    "No file uploaded" : "Faili ei laetud üles",
    "Unsupported image type" : "Pildi tüüp pole toetatud",
    "You are already using a custom theme" : "Kohandatud teema on juba kasutusel",
    "Theming" : "Teemad",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teemad võimaldavad lihtsalt serveriinstantsi ja toetatud klientide välimus muuta. See on näha kõigile kasutajatele.",
    "Name" : "Nimi",
    "Reset to default" : "Taasta vaikeseaded",
    "Web address" : "Veebiaadress",
    "Web address https://…" : "Veebiaadress https://...",
    "Slogan" : "Tunnuslause",
    "Color" : "Värv",
    "Logo" : "Logo",
    "Upload new logo" : "Lae üles uus logo",
    "Login image" : "Avalehe taust",
    "Upload new login background" : "Lae üles uus avalehe taustapilt",
    "Remove background image" : "Eemalda taustapilt",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Paigalda Imagemagick PHP laiendus SVG piltide toega, et üleslaetud logo ja värvi põhjal automaatselt faviconid genereerida. ",
    "reset to default" : "taasta vaikeseaded",
    "The uploaded file was only partially uploaded" : "Üleslatud fail laeti üles ainult osaliselt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/theming/l10n/et_EE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Eelvaate laadimine...",
    "Saved" : "Salvestatud",
    "Admin" : "Haldur",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "The given name is too long" : "Antud nimi on liiga pikk",
    "The given web address is too long" : "Antud veebiaadress on liiga pikk",
    "The given slogan is too long" : "Antud tunnuslause on liiga pikk",
    "The given color is invalid" : "Antud värv ei sobi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaetud fail on suurem, kui php.ini failis määratud upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail on suurem, kui MAX_FILE_SIZE atribuut, mis seadistati HTML vormis",
    "No file was uploaded" : "Ühtegi faili ei latud üles",
    "Missing a temporary folder" : "Ajutine kausta on puudu",
    "No file uploaded" : "Faili ei laetud üles",
    "Unsupported image type" : "Pildi tüüp pole toetatud",
    "Theming" : "Teemad",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teemad võimaldavad lihtsalt serveriinstantsi ja toetatud klientide välimus muuta. See on näha kõigile kasutajatele.",
    "Name" : "Nimi",
    "Reset to default" : "Taasta vaikeseaded",
    "Slogan" : "Tunnuslause",
    "Color" : "Värv",
    "Logo" : "Logo",
    "Upload new logo" : "Lae üles uus logo",
    "Login image" : "Avalehe taust",
    "Upload new login background" : "Lae üles uus avalehe taustapilt",
    "Remove background image" : "Eemalda taustapilt",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Paigalda Imagemagick PHP laiendus SVG piltide toega, et üleslaetud logo ja värvi põhjal automaatselt faviconid genereerida. ",
    "There is no error, the file uploaded with success" : "Vigu pole, fail laetu edukalt üles",
    "The uploaded file was only partially uploaded" : "Üleslatud fail laeti üles ainult osaliselt",
    "Failed to write file to disk." : "Faili kettale kirjutamine ebaõnnestus.",
    "A PHP extension stopped the file upload." : "PHP laiendus seiskas faili üleslaadimise.",
    "You are already using a custom theme" : "Kohandatud teema on juba kasutusel",
    "Web address https://…" : "Veebiaadress https://..."
},
"nplurals=2; plural=(n != 1);");
